#!/bin/bash
set -x

# This is a simple script that will run the lv-store-vacuum command on the store path supplied
# The output of the command are published to the CServerLog table

if [ -z $1 ] ; then
    echo "vacuum.sh: You must supply a store directory path"
    exit -1
fi
store_path=$1
LVCLIENT="lv-client"
LVSTOREVACUUM="lv-store-vacuum"

noop=`$LVCLIENT --version`
if [ $? -ne 0 ] ; then
    echo "Problem with lv-client. Is it on the PATH?"
    exit -1
fi
liveview_uri="lv://localhost:10080"
table_name="Logs"

logger_name="LVInfoStore"
log_ts=`date "+%Y%m%d%H%M%S"`
vacuum_log="/tmp/vacuum-$log_ts.log"
appender_name="VacuumReporter"

# do the vacuum
$LVSTOREVACUUM -d $store_path 2>&1 > $vacuum_log

# Now publish the results to the log table
# use the current millis as the starting index
# this is only a little weak, as the index will collide after 1.5 billion syslog messages
index=`date +%s`
ts=`date "+%Y-%m-%d %H:%M:%S.000%z"`

# ID,rawMessage,receiptTime,priority,facility,severity,sourceTime,hostname,appName,procID,msgID,structuredData,msg
while read -r line
do
    echo $index,null,"\"$ts\"",null,16,6,"\"$ts\"","localhost","lv-store-vacuum",null,null,null,"\"$line\"" | $LVCLIENT -u $liveview_uri publish $table_name
    ((index=$index+1))
done < "$vacuum_log"
